PlanarImage

Struct PlanarImage 

pub struct PlanarImage<T, const CHANNELS: usize> { /* private fields */ }
An owning, densely packed planar image.

Storage order is all values for channel 0, followed by channel 1, and so on.

Implementations

Source

impl<T, const CHANNELS: usize> PlanarImage<T, CHANNELS>

pub fn try_new( width: usize, height: usize, data: Vec<T>, ) -> Result<Self, ImageError>

Creates an image from densely packed planar scalar elements.

pub fn try_new_with_metadata( width: usize, height: usize, data: Vec<T>, metadata: ImageMetadata, ) -> Result<Self, ImageError>

Creates a planar image with validated semantic metadata.

pub const fn width(&self) -> usize

Returns image width in pixels.

pub const fn height(&self) -> usize

Returns image height in pixels.

pub const fn layout(&self) -> ImageLayout

Returns physical channel layout.

pub const fn row_stride(&self) -> usize

Returns packed row stride within each plane.

pub const fn plane_stride(&self) -> usize

Returns the scalar distance between channel-plane origins.

pub const fn metadata(&self) -> ImageMetadata

Returns semantic image metadata.

pub fn set_metadata( &mut self, metadata: ImageMetadata, ) -> Result<(), ImageError>

Replaces semantic metadata after validating the channel count.

pub fn as_slice(&self) -> &[T]

Returns planar scalar storage.

pub fn as_mut_slice(&mut self) -> &mut [T]

Returns mutable planar scalar storage.

pub fn view(&self) -> PlanarImageView<'_, T, CHANNELS>

Borrows this image as a planar view.

pub fn get(&self, channel: usize, x: usize, y: usize) -> Option<&T>

Returns one channel value, or None outside image bounds.

pub fn get_mut(&mut self, channel: usize, x: usize, y: usize) -> Option<&mut T>

Returns one mutable channel value, or None outside image bounds.

pub fn into_vec(self) -> Vec<T>

Consumes the image and returns planar scalar storage.